@@ -67,14 +67,12 @@ class Plugin:
         path = os.path.sep.join(
             it.chain([os.path.sep], *zip(it.repeat("properties"), path)))
         property_ = util.get_value(schema, path)
-        defaults = {
-            'choices': property_.get('enum'),
-            'help': property_.get('description')
-        }
-        if 'type' in property_:
-            defaults['type'] = util.TYPES[property_['type']]
-        defaults.update(kwargs)
-        return parser.add_argument(name, **defaults)
+        kwargs.setdefault('choices', property_.get('enum'))
+        kwargs.setdefault('help', property_.get('description'))
+        type_ = property_.get('type')
+        if type_:
+            kwargs.setdefault('type', util.TYPES[type_])
+        return parser.add_argument(name, **kwargs)
 
     def add_arguments(self, parser):
         """
@@ -305,7 +303,7 @@ class BasePlugin(Plugin):
         if configuration is None and os.path.isfile(args.file):
             filename = os.path.abspath(args.file)
             with open(filename) as fp:  # pylint: disable=invalid-name
-                configuration = yaml.load(fp)
+                configuration = yaml.safe_load(fp)
             self.logger.debug("loaded configuration from '%s'", filename)
             dirname = os.path.dirname(filename)
             configuration['workspace'] = os.path.join(dirname, configuration.get('workspace', '.'))
